@@ -38,6 +38,7 @@ public:
 signals:
     void dial(const QString &);
     void hangUp();
+    void sendDTMF(const QChar);
 
 public slots:
     void ringing(const QString &);
@@ -50,6 +51,7 @@ protected slots:
     void doHangUp();
 private:
     bool callInitialized;
+    bool isConnected;
 };
 
 #endif
