@@ -40,7 +40,7 @@ public:
     ~MyTextChannelHandler();
 
     /** @brief A implementation of the ChannelHandler interface's only method. */
-    bool handleChannel(QtTapioca::Connection *, QtTapioca::Channel *);
+    bool handleChannel(QtTapioca::Connection *, QtTapioca::Channel *, const bool);
 
 public slots:
 
