@@ -91,5 +91,5 @@ bool Decibel::ChannelHandler::handleChannel(const Decibel::ChannelInfo & channel
         return false;
     }
 
-    return handleChannel(connection, channel);
+    return handleChannel(connection, channel, channel_info.incoming);
 }
