@@ -21,6 +21,7 @@
 #include <Decibel/Types>
 
 #include <QtCore/QStringList>
+#include <QtCore/QDateTime>
 
 #include <QtTapioca/ConnectionManagerFactory>
 #include <QtTapioca/Connection>
@@ -30,13 +31,14 @@
 // ChannelInfo:
 
 Decibel::ChannelInfo::ChannelInfo() :
-        channel_type(0),
-        target_handle_type(0),
-        target_handle(0)
+    channel_type(0),
+    target_handle_type(0),
+    target_handle(0)
 { }
 
 Decibel::ChannelInfo::ChannelInfo(const QtTapioca::Connection * connection,
-                                  const QtTapioca::Channel * channel)
+                                  const QtTapioca::Channel * channel,
+                                  const bool isIncoming)
 {
     Q_ASSERT(0 != connection);
     Q_ASSERT(0 != channel);
@@ -45,6 +47,7 @@ Decibel::ChannelInfo::ChannelInfo(const QtTapioca::Connection * connection,
     channel_service = channel->serviceName();
     channel_path = QDBusObjectPath(channel->objectPath());
     channel_type = channel->type();
+    incoming = isIncoming;
     Q_ASSERT(0 != channel->target());
     Q_ASSERT(0 != channel->target()->handle());
     target_handle_type = channel->target()->handle()->type();
@@ -58,7 +61,8 @@ Decibel::ChannelInfo::ChannelInfo(const Decibel::ChannelInfo & channel_info) :
     channel_path(channel_info.channel_path),
     channel_type(channel_info.channel_type),
     target_handle_type(channel_info.target_handle_type),
-    target_handle(channel_info.target_handle)
+    target_handle(channel_info.target_handle),
+    incoming(channel_info.incoming)
 { }
 
 QtTapioca::Connection * Decibel::ChannelInfo::connection(QObject * parent) const
@@ -78,8 +82,8 @@ QtTapioca::Channel * Decibel::ChannelInfo::channel() const
     {
         if (channel->serviceName() == channel_service &&
             channel->objectPath() == channel_path.path() &&
-            channel->target()->handle()->type() == target_handle_type &&
-            channel->target()->handle()->id() == target_handle &&
+            // channel->target()->handle()->type() == target_handle_type &&
+            // channel->target()->handle()->id() == target_handle &&
             channel->type() == channel_type)
         { return channel; }
     }
@@ -99,6 +103,7 @@ Decibel::ChannelInfo::operator = (const Decibel::ChannelInfo & channel_info)
     channel_type = channel_info.channel_type;
     target_handle_type = channel_info.target_handle_type;
     target_handle = channel_info.target_handle;
+    incoming = channel_info.incoming;
     return *this;
 }
 
@@ -112,7 +117,8 @@ const QDBusArgument & operator << (QDBusArgument & arg,
         << channel_info.channel_path
         << channel_info.channel_type
         << channel_info.target_handle_type
-        << channel_info.target_handle;
+        << channel_info.target_handle
+        << channel_info.incoming;
     arg.endStructure();
     return arg;
 }
@@ -127,7 +133,8 @@ const QDBusArgument & operator >> (const QDBusArgument & arg,
         >> channel_info.channel_path
         >> channel_info.channel_type
         >> channel_info.target_handle_type
-        >> channel_info.target_handle;
+        >> channel_info.target_handle
+        >> channel_info.incoming;
     arg.endStructure();
     return arg;
 
@@ -137,11 +144,13 @@ const QDBusArgument & operator >> (const QDBusArgument & arg,
 
 Decibel::ComponentInfo::ComponentInfo() { }
 
-Decibel::ComponentInfo::ComponentInfo(const QStringList & protocols,
+Decibel::ComponentInfo::ComponentInfo(const QString & name,
+                                      const QStringList & protocols,
                                       const QList<int> & types,
                                       const QList<int> & targets,
                                       const QString & service,
                                       const QDBusObjectPath & path) :
+    display_name(name),
     possible_protocol_list(protocols),
     possible_type_list(types),
     possible_target_type_list(targets),
@@ -150,6 +159,7 @@ Decibel::ComponentInfo::ComponentInfo(const QStringList & protocols,
 { }
 
 Decibel::ComponentInfo::ComponentInfo(const Decibel::ComponentInfo & info) :
+    display_name(info.display_name),
     possible_protocol_list(info.possible_protocol_list),
     possible_type_list(info.possible_type_list),
     possible_target_type_list(info.possible_target_type_list),
@@ -166,11 +176,38 @@ bool Decibel::ComponentInfo::sameObject(const Decibel::ComponentInfo & info) con
     { return false; }
 }
 
+// LogEntry:
+
+Decibel::LogEntry::LogEntry() { }
+
+Decibel::LogEntry::LogEntry(const LogEntry & in) :
+    startTime(in.startTime),
+    connectTime(in.connectTime),
+    endTime(in.endTime),
+    protocol(in.protocol),
+    incoming(in.incoming),
+    contacts(in.contacts)
+{ }
+
+Decibel::LogEntry::LogEntry(const uint st, const uint ct, const uint et,
+                            const QString & proto, const bool ic,
+                            const QStringList cont) :
+    startTime(st), connectTime(ct), endTime(et),
+    protocol(proto), incoming(ic),
+    contacts(cont)
+{ }
+
+Decibel::LogEntry::~LogEntry()
+{ }
+
+// Operater >> and <<:
+
 const QDBusArgument & operator << (QDBusArgument & arg,
                                    const Decibel::ComponentInfo & info)
 {
     arg.beginStructure();
-    arg << info.possible_protocol_list
+    arg << info.display_name
+        << info.possible_protocol_list
         << info.possible_type_list
         << info.possible_target_type_list
         << info.service_name
@@ -183,7 +220,8 @@ const QDBusArgument & operator >> (const QDBusArgument & arg,
                                    Decibel::ComponentInfo & info)
 {
     arg.beginStructure();
-    arg >> info.possible_protocol_list
+    arg >> info.display_name
+        >> info.possible_protocol_list
         >> info.possible_type_list
         >> info.possible_target_type_list
         >> info.service_name
@@ -197,13 +235,15 @@ const QDBusArgument & operator >> (const QDBusArgument & arg,
 Decibel::Component::Component() { }
 
 Decibel::Component::Component(const uint handle) :
-    component_handle(handle)
+     component_handle(handle)
 { }
 
-Decibel::Component::Component(const QStringList & protocols,
+Decibel::Component::Component(const QString & name,
+                              const QStringList & protocols,
                               const QList<int> & types,
                               const QList<int> & targets,
                               const uint handle) :
+    display_name(name),
     protocol_list(protocols),
     type_list(types),
     target_type_list(targets),
@@ -211,6 +251,7 @@ Decibel::Component::Component(const QStringList & protocols,
 { }
 
 Decibel::Component::Component(const Decibel::Component & component) :
+    display_name(component.display_name),
     protocol_list(component.protocol_list),
     type_list(component.type_list),
     target_type_list(component.target_type_list),
@@ -221,7 +262,8 @@ const QDBusArgument & operator << (QDBusArgument & arg,
                                    const Decibel::Component & component)
 {
     arg.beginStructure();
-    arg << component.protocol_list
+    arg << component.display_name
+        << component.protocol_list
         << component.type_list
         << component.target_type_list
         << component.component_handle;
@@ -233,7 +275,8 @@ const QDBusArgument & operator >> (const QDBusArgument & arg,
                                    Decibel::Component & component)
 {
     arg.beginStructure();
-    arg >> component.protocol_list
+    arg >> component.display_name
+        >> component.protocol_list
         >> component.type_list
         >> component.target_type_list
         >> component.component_handle;
@@ -241,6 +284,34 @@ const QDBusArgument & operator >> (const QDBusArgument & arg,
     return arg;
 }
 
+const QDBusArgument & operator << (QDBusArgument & arg,
+                                   const Decibel::LogEntry & entry)
+{
+    arg.beginStructure();
+    arg << entry.startTime
+        << entry.connectTime
+        << entry.endTime
+        << entry.protocol
+        << entry.incoming
+        << entry.contacts;
+    arg.endStructure();
+    return arg;
+}
+
+const QDBusArgument & operator >> (const QDBusArgument & arg,
+                                   Decibel::LogEntry & entry)
+{
+    arg.beginStructure();
+    arg >> entry.startTime
+        >> entry.connectTime
+        >> entry.endTime
+        >> entry.protocol
+        >> entry.incoming
+        >> entry.contacts;
+    arg.endStructure();
+    return arg;
+}
+
 // Helper functions:
 
 void Decibel::registerTypes()
@@ -252,6 +323,7 @@ void Decibel::registerTypes()
         qDBusRegisterMetaType<Decibel::ChannelInfo>();
         qDBusRegisterMetaType<Decibel::ComponentInfo>();
         qDBusRegisterMetaType<Decibel::Component>();
+        qDBusRegisterMetaType<Decibel::LogEntry>();
         qDBusRegisterMetaType<QList<Decibel::Component> >();
 
         // types from QtTapioca:
