@@ -456,6 +456,10 @@ void AccountManager::bringUpAccounts()
         Q_ASSERT(d->m_accounts[i].data.contains(Decibel::name_presence_message));
         Q_ASSERT(d->m_accounts[i].data.contains(Decibel::name_autoreconnect));
 
+        if (d->m_accounts[i].data[Decibel::name_presence] ==
+            QtTapioca::ContactBase::Offline)
+        { continue; }
+
         qDebug() << "Bringing up" << i << ":"
                  << d->m_accounts[i].data[Decibel::name_protocol]
                  << "ip:" << d->m_accounts[i].data[Decibel::name_presence]
@@ -507,10 +511,21 @@ uint AccountManager::addAccount(const QVariantMap & nv_pairs)
     if (!matching_accounts.isEmpty()) { return matching_accounts[0]; }
 
     QVariantMap data = d->sanityCheck(nv_pairs);
-    if (data.isEmpty()) { return 0; }
+    if (data.isEmpty())
+    {
+        sendErrorReply(Decibel::ErrorDataIncomplete,
+                       tr("Account data was incomplete"));
+        return 0;
+    }
     uint account_handle = d->createAccount(data);
 
     if (account_handle != 0) { emit accountCreated(account_handle); }
+    else
+    {
+        sendErrorReply(Decibel::ErrorInternalError,
+                       tr("Failed to store account information."));
+        return 0;
+    }
 
     Q_ASSERT(d->m_accounts.size() == num_accounts + 1);
 
@@ -541,7 +556,12 @@ uint AccountManager::updateAccount(const uint account_handle,
     // make sure the data is sane:
     data = d->sanityCheck(data);
 
-    if (data.isEmpty()) { return 0; }
+    if (data.isEmpty())
+    {
+        sendErrorReply(Decibel::ErrorDataIncomplete,
+                       tr("Update invalidates the data."));
+        return 0;
+    }
 
     d->m_accounts[account_handle] = data;
     if (presence_state != presence(account_handle) &&
@@ -600,10 +620,19 @@ int AccountManager::setPresence(const uint account_handle,
 {
     if (presence_state < QtTapioca::ContactBase::Offline ||
         presence_state > QtTapioca::ContactBase::Busy)
-    { return Decibel::ERROR_INVALID_PRESENCE; }
+    {
+        sendErrorReply(Decibel::ErrorInvalidValue,
+                       tr("Presence is not valid."));
+        return -1;
+    }
 
     if (!d->gotAccount(account_handle))
-    { return Decibel::ERROR_NO_SUCH_ACCOUNT; }
+    {
+        sendErrorReply(Decibel::ErrorNoSuchAccount,
+                       tr("Account %s not found.", "1: account_handle").
+                           arg(account_handle));
+        return -1;
+    }
 
     if (presence(account_handle) == presence_state) { return presence_state; }
 
@@ -620,7 +649,12 @@ int AccountManager::setPresence(const uint account_handle,
 int AccountManager::presence(const uint account_handle)
 {
     if (!d->gotAccount(account_handle))
-    { return Decibel::ERROR_NO_SUCH_ACCOUNT; }
+    {
+        sendErrorReply(Decibel::ErrorNoSuchAccount,
+                       tr("Account %s not found.", "1: account_handle").
+                           arg(account_handle));
+        return -1;
+    }
 
     Q_ASSERT(d->m_accounts[account_handle].data.contains(Decibel::name_presence));
     int result = d->m_accounts[account_handle].data[Decibel::name_presence].toInt();
@@ -632,7 +666,12 @@ int AccountManager::presence(const uint account_handle)
 int AccountManager::currentPresence(const uint account_handle)
 {
     if (!d->gotAccount(account_handle))
-    { return Decibel::ERROR_NO_SUCH_ACCOUNT; }
+    {
+        sendErrorReply(Decibel::ErrorNoSuchAccount,
+                       tr("Account %s not found.", "1: account_handle").
+                           arg(account_handle));
+        return -1;
+    }
 
     Q_ASSERT(d->m_accounts[account_handle].data.contains(Decibel::name_current_presence));
     int result = d->m_accounts[account_handle].data[Decibel::name_current_presence].toInt();
@@ -645,7 +684,12 @@ int AccountManager::setPresenceMessage(const uint account_handle,
                                        const QString & message)
 {
     if (!d->gotAccount(account_handle))
-    { return Decibel::ERROR_NO_SUCH_ACCOUNT; }
+    {
+        sendErrorReply(Decibel::ErrorNoSuchAccount,
+                       tr("Account %s not found.", "1: account_handle").
+                           arg(account_handle));
+        return -1;
+    }
 
     int result = 0;
     if (0 != d->connectionOf(account_handle))
@@ -678,7 +722,13 @@ int AccountManager::setPresenceAndMessage(const uint account_handle,
                                           const QString & message)
 {
     if (!d->gotAccount(account_handle))
-    { return Decibel::ERROR_NO_SUCH_ACCOUNT; }
+    {
+        sendErrorReply(Decibel::ErrorNoSuchAccount,
+                       tr("Account %s not found.", "1: account_handle").
+                           arg(account_handle));
+        return -1;
+    }
+
     int result = 0;
     result = d->manageConnection(account_handle,
                                QtTapioca::ContactBase::Presence(presence_state),
