@@ -22,7 +22,8 @@
 #define _DECIBEL_DAEMON_ACCOUNTMANAGER_H_
 
 #include <QtCore/QObject>
-#include <QtDBus/QDBusMessage>
+
+#include <QtDBus/QDBusContext>
 
 #include <Decibel/Types>
 
@@ -54,10 +55,9 @@ class AccountManagerPrivate;
  *
  * @author Tobias Hunger <info@basyskom.de>
  */
-class AccountManager : public QObject
+class AccountManager : public QObject, protected QDBusContext
 {
     Q_OBJECT
-    Q_DECLARE_PRIVATE(AccountManager)
 
 public:
     /**
@@ -134,7 +134,10 @@ public slots:
     /**
      * @brief Add a new account.
      * @param nv_pairs A list of name value pairs defining the account.
-     * @returns A handle to the new account or a negative error code.
+     * @returns A handle to the new account.
+     * @throws data_incomplete Some required information was missing.
+     * @throws internal_error Something unexpected happened trying to store
+     *    the account information.
      *
      * Add a new set of data as an account. The QVariantMap must not be empty
      * and may not conflict with an existing account. The account is not
@@ -144,18 +147,6 @@ public slots:
      * Prerequisites:
      *  * One NVPair must have a name of "protocol" and a value-type of
      *    QString.
-     *  * No name may appear twice in the list.
-     *
-     * Returns a non-negative handle on success.
-     * Errorcodes:
-     *  ERROR_EMPTY_LIST:
-     *    Given list of QVariantMap was empty
-     *  ERROR_NO_PROTOCOL:
-     *    No name "protocol" found.
-     *  ERROR_WRONG_VALUE_TYPE_FOR_PROTOCOL:
-     *    name "protocol" has value which is not of type QString
-     *  ERROR_DUPLICATE_NAME:
-     *    name seen more than once in the list passed in.
      */
     uint addAccount(const QVariantMap & nv_pairs);
 
@@ -205,6 +196,8 @@ public slots:
      * @param account_handle A handle to the account to update.
      * @param presence_state The new presence state.
      * @returns A positive value or a negative error code.
+     * @throws no_such_account if the account is invalid.
+     * @throws invalid_value if the presence is invalid.
      *
      * Set the presence information on an account and update the online
      * state accordingly.
@@ -215,6 +208,7 @@ public slots:
      * @brief Get the intended presence state of a account.
      * @param account_handle A handle to the account to examine.
      * @returns The current presence state.
+     * @throws no_such_account if the account is invalid.
      *
      * Get the presence state of an account.
      */
@@ -224,6 +218,7 @@ public slots:
      * @brief Get the current presence state of a account.
      * @param account_handle A handle to the account to examine.
      * @returns The current presence state.
+     * @throws no_such_account if the account is invalid.
      *
      * Get the presence state of an account.
      */
@@ -233,7 +228,8 @@ public slots:
      * @brief Set the presence message of the given account.
      * @param account_handle A handle to the account to update.
      * @param message The new presence message.
-     * @returns A positive value on success or a negative error code.
+     * @returns A positive value on success.
+     * @throws no_such_account if the account is invalid.
      *
      * Set the presence message of the given account.
      */
@@ -243,6 +239,7 @@ public slots:
      * @brief Get the presence message of the given account.
      * @param account_handle A handle to the account to examine.
      * @returns The current presence message.
+     * @throws no_such_account if the account is invalid.
      *
      * Get the presence message of the given account.
      */
@@ -254,6 +251,8 @@ public slots:
      * @param presence_state The new presence state to set.
      * @param message The new presence message to set.
      * @returns A positive value on success or a negative error code.
+     * @throws no_such_account if the account is invalid.
+     * @throws invalid_value if the presence is invalid.
      *
      * Set the presence state and the presence message at the same time.
      *
@@ -272,6 +271,8 @@ public slots:
      * account.
      *
      * It is empty if the account is offline.
+     *
+     * This is a method used internally and is not exported to D-Bus.
      */
     QString serviceName(const uint account_handle) const;
 
@@ -284,6 +285,8 @@ public slots:
      * account.
      *
      * It is empty if the account is offline.
+     *
+     * This is a method used internally and is not exported to D-Bus.
      */
     QString objectPath(const uint account_handle) const;
 
