@@ -45,6 +45,7 @@ namespace
 
     static const QString search_path_key("Search Path");
 
+    static const QString display_name_key("Name");
     static const QString protocols_list_key("Protocols");
     static const QString types_list_key("Types");
     static const QString target_types_list_key("Targets");
@@ -116,6 +117,8 @@ public:
                 foreach (key, keys)
                 {
                     QVariant value = settings.value(key);
+                    if (display_name_key == key)
+                    { component.display_name = value.toString(); }
                     if (protocols_list_key == key)
                     { component.protocol_list = value.toString().split(";", QString::SkipEmptyParts); }
                     else if (types_list_key == key)
@@ -201,9 +204,12 @@ public:
             {
                 settings.setArrayIndex(i);
 
+                // display_name:
+                settings.setValue(display_name_key,
+                                  profiles[profile_name][i].display_name);
                 // protocols:
                 settings.setValue(protocols_list_key,
-                                 profiles[profile_name][i].protocol_list.join(QString(';')));
+                                  profiles[profile_name][i].protocol_list.join(QString(';')));
 
                 // types:
                 QString tmp;
@@ -278,10 +284,12 @@ public:
                 { break; }
             }
 
+            Decibel::Component component(component_handle);
+            component.display_name = components[component_handle].display_name;
             if (i == profile.size())
-            { profile.append(Decibel::Component(component_handle)); }
+            { profile.append(component); }
             else
-            { profile[i] = Decibel::Component(component_handle); }
+            { profile[i] = component; }
         }
         profiles.insert(fallback_profile_name, profile);
     }
@@ -324,7 +332,9 @@ public:
                 {
                     QVariant value(component_settings.value(key));
 
-                    if (protocols_list_key == key)
+                    if (display_name_key == key)
+                    { info.display_name = value.toString(); }
+                    else if (protocols_list_key == key)
                     { info.possible_protocol_list = value.toString().split(";", QString::SkipEmptyParts); }
                     else if (types_list_key == key)
                     {
@@ -411,6 +421,7 @@ public:
                 }
 
                 qDebug() << "Component:";
+                qDebug() << "    display name:" << info.display_name;
                 qDebug() << "    protocols   :" << info.possible_protocol_list;
                 qDebug() << "    types       :" << info.possible_type_list;
                 qDebug() << "    target_types:" << info.possible_target_type_list;
