@@ -23,6 +23,8 @@
 
 #include <QtCore/QObject>
 
+#include <QtDBus/QDBusContext>
+
 #include <Decibel/Types>
 
 class ComponentManagerPrivate;
@@ -79,10 +81,9 @@ class ComponentManagerPrivate;
  *
  * @author Tobias Hunger <info@basyskom.de>
  */
-class ComponentManager : public QObject
+class ComponentManager : public QObject, protected QDBusContext
 {
     Q_OBJECT
-    Q_DECLARE_PRIVATE(ComponentManager)
 
 public:
     /** @brief Constructor */
