@@ -298,7 +298,7 @@ public:
         newChannelList.append(qMakePair(connection, channel));
         QTimer::singleShot(10, contactManager, SLOT(onNewChannelCreated()));
 
-        Decibel::ChannelInfo channel_info(connection, channel);
+        Decibel::ChannelInfo channel_info(connection, channel, false);
 
         Q_ASSERT(!channel_info.isNull());
         return channel_info;
@@ -600,6 +600,8 @@ void ContactManager::onNewChannelCreated()
 {
     QPair<QtTapioca::Connection *, QtTapioca::Channel *> pair;
     foreach (pair, d->newChannelList)
-    { emit channelOpened(pair.first, pair.second); }
+    {
+        emit channelOpened(pair.first, pair.second, false);
+    }
     d->newChannelList.clear();
 }
